
# This file was generated by 'versioneer.py' (0.28) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2023-06-01T21:39:55+0000",
 "dirty": false,
 "error": null,
 "full-revisionid": "bba3d3f2a1edf5b42160d8f081b676cd4e9b9a41",
 "version": "v23.08.00a230605"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
